"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.IntegrationWidget = void 0;
var IntegrationWidget = /** @class */ (function () {
    function IntegrationWidget(elementId, params, iframeParams) {
        var _a;
        this.iframeElement = null;
        this.progressBarElement = null;
        this.entityId = this.generateEntityId();
        this.baseUrl = (_a = iframeParams === null || iframeParams === void 0 ? void 0 : iframeParams.baseUrl) !== null && _a !== void 0 ? _a : 'https://widget.nepflow.dev';
        this.params = params;
        this.iframeParams = iframeParams !== null && iframeParams !== void 0 ? iframeParams : {};
        // Get the widget element
        this.widgetElement = document.getElementById(elementId);
        if (!this.widgetElement) {
            console.error('Integration widget element not found.');
            return;
        }
        this.widgetElement.innerHTML = '';
        // Append the progress bar
        if (!this.params.hideIframeProgressBar) {
            this.progressBarElement = this.createProgressBar();
            this.widgetElement.appendChild(this.progressBarElement);
        }
        // Append the iframe
        this.iframeElement = this.createIFrame();
        this.widgetElement.appendChild(this.iframeElement);
        this.setupMessageHandler(this.iframeElement);
    }
    IntegrationWidget.prototype.createProgressBar = function () {
        // Add a CSS rotation animation
        var styleSheet = document.createElement('style');
        styleSheet.type = 'text/css';
        styleSheet.innerText = "\n    @keyframes nepflowWidgetProgressBarRotate {\n      from { transform: rotate(0deg); }\n      to { transform: rotate(360deg); }\n    }";
        (document.head || document.body).appendChild(styleSheet);
        // Create progress bar container
        var progressBar = document.createElement('div');
        progressBar.style.position = 'relative';
        progressBar.style.backgroundColor = this.params.backgroundColor;
        progressBar.style.width = '100%';
        progressBar.style.minHeight = '100px';
        // Show only after 0.3s
        progressBar.style.opacity = '0';
        progressBar.style.transition = '0.3s';
        setTimeout(function () {
            progressBar.style.opacity = '1';
        }, 0);
        // Create progress bar icon
        var progressBarIcon = document.createElement('div');
        progressBarIcon.style.backgroundImage = 'url(\'data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" class="icon icon-tabler icon-tabler-loader-2" width="24" height="24" viewBox="0 0 24 24" stroke-width="2" stroke="currentColor" fill="none" stroke-linecap="round" stroke-linejoin="round"><path stroke="none" d="M0 0h24v24H0z" fill="none"/><path d="M12 3a9 9 0 1 0 9 9" /></svg>\')';
        progressBarIcon.style.position = 'absolute';
        progressBarIcon.style.top = '50%';
        progressBarIcon.style.left = '50%';
        progressBarIcon.style.margin = '-18px 0 0 -18px';
        progressBarIcon.style.backgroundSize = '100% 100%';
        progressBarIcon.style.backgroundPosition = 'center center';
        progressBarIcon.style.opacity = '0.5';
        progressBarIcon.style.width = '36px';
        progressBarIcon.style.height = '36px';
        progressBarIcon.style.animation = 'nepflowWidgetProgressBarRotate 0.5s linear infinite';
        progressBar.appendChild(progressBarIcon);
        return progressBar;
    };
    IntegrationWidget.prototype.hideProgressBar = function () {
        if (this.progressBarElement) {
            this.progressBarElement.style.display = 'none';
        }
    };
    IntegrationWidget.prototype.getSearchParams = function () {
        // Create URLSearchParams from the params object
        var searchParams = new URLSearchParams();
        for (var _i = 0, _a = Object.entries(this.params); _i < _a.length; _i++) {
            var _b = _a[_i], key = _b[0], value = _b[1];
            if (typeof value === 'boolean') {
                searchParams.append(key, value ? 'true' : '');
            }
            else if (typeof value === 'object') {
                searchParams.append(key, JSON.stringify(value));
            }
            else if (typeof value === 'number') {
                searchParams.append(key, value.toString());
            }
            else if (typeof value === 'string') {
                searchParams.append(key, value);
            }
        }
        // Add widgetId
        searchParams.append('entityId', this.entityId);
        // Add parent window host
        searchParams.append('appHost', window.location.host);
        return searchParams;
    };
    // Create the iframe element
    IntegrationWidget.prototype.createIFrame = function () {
        var _a, _b, _c, _d, _e, _f;
        var searchParams = this.getSearchParams();
        var iframe = document.createElement('iframe');
        iframe.src = "".concat(this.baseUrl, "/").concat(this.params.zapierAppId || '', "?").concat(searchParams.toString());
        iframe.style.width = (_b = (_a = this.iframeParams) === null || _a === void 0 ? void 0 : _a.width) !== null && _b !== void 0 ? _b : '100%';
        iframe.style.height = (_d = (_c = this.iframeParams) === null || _c === void 0 ? void 0 : _c.height) !== null && _d !== void 0 ? _d : '100%';
        iframe.style.minHeight = (_f = (_e = this.iframeParams) === null || _e === void 0 ? void 0 : _e.minHeight) !== null && _f !== void 0 ? _f : '500px';
        iframe.frameBorder = '0';
        return iframe;
    };
    // Setup handler for messages from the iframe
    IntegrationWidget.prototype.setupMessageHandler = function (iframe) {
        var _this = this;
        window.addEventListener('message', function (event) {
            if (!event.origin.startsWith(_this.baseUrl)) {
                console.debug('[Nepflow] Received message from unknown origin', event.origin);
                return;
            }
            var _a = event.data, action = _a.action, data = _a.data, receivedEntityId = _a.entityId;
            if (receivedEntityId !== _this.entityId) {
                return;
            }
            console.debug('[Nepflow] Received message:', action, data);
            switch (action) {
                case 'handleLoaded':
                    _this.hideProgressBar();
                    break;
                case 'setWidgetHeight':
                    iframe.style.height = "".concat(data.widgetHeight, "px");
                    break;
                case 'handleCardClick':
                    if (typeof _this.params.onCardClick === 'function') {
                        _this.params.onCardClick(data.id);
                    }
                    ;
                    break;
            }
        });
    };
    // Generate unique entity id
    IntegrationWidget.prototype.generateEntityId = function () {
        var prefix = 'integration-widget-';
        var randomSuffix = Math.random().toString(36).substring(2, 15) + Math.random().toString(36).substring(2, 15);
        return prefix + randomSuffix;
    };
    return IntegrationWidget;
}());
exports.IntegrationWidget = IntegrationWidget;
//# sourceMappingURL=IntegrationWidget.js.map